/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Platform for Privacy Preferences.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2002
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Harish Dhurvasula <harishd@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsICategoryManager.h"
#include "nsIComponentManager.h"
#include "nsIGenericFactory.h"
#include "nsIHttpProtocolHandler.h"
#include "nsIServiceManager.h"
#include "nsP3PCIID.h"
#include "nsP3PService.h"
#include "nsCompactPolicy.h"
#include "nsPolicyReference.h"

NS_GENERIC_FACTORY_CONSTRUCTOR_INIT(nsP3PService,Init)
NS_GENERIC_FACTORY_CONSTRUCTOR(nsPolicyReference)

static nsModuleComponentInfo gP3PComponents[] =
{
  {"P3P Service",
   NS_P3PSERVICE_CID,
   NS_COOKIECONSENT_CONTRACTID,
   nsP3PServiceConstructor,
  },
  {"Policy Reference",
   NS_POLICYREFERENCE_CID,
   "@mozilla.org/p3p/policyreference;1",
   nsPolicyReferenceConstructor,
  }
};

PR_STATIC_CALLBACK(nsresult)
Initialize(nsIModule* aSelf)
{
  return nsCompactPolicy::InitTokenTable(); 
}

PR_STATIC_CALLBACK(void)
Shutdown(nsIModule* aSelf)
{
  nsCompactPolicy::DestroyTokenTable();
}

NS_IMPL_NSGETMODULE_WITH_CTOR_DTOR(nsP3PModule, gP3PComponents,Initialize,Shutdown)

